Txtdist is small utility crate for calculating the distance between two strings.
Functions
- damerau_
levenshtein - Calculate the distance between two strings using the damerau levenshtein algorithm.
- levenshtein
- Calculate the distance between two strings using the levenshtein algorithm.